pub struct ConvexHullWrapper<T: Float + ToBigInt> {
pub inner: ConvexHull<BigInt>,
pub conversion_factor: T,
}Expand description
A wrapper that holds a given points as a bigint. This can compute a convex hull robustly, although the computation is slower.
Fields
inner: ConvexHull<BigInt>conversion_factor: TImplementations
Sourceimpl<T: Float + ToBigInt> ConvexHullWrapper<T>
impl<T: Float + ToBigInt> ConvexHullWrapper<T>
pub fn try_new( points: &[Vec<T>], max_iter: Option<usize>, ) -> Result<Self, ErrorKind>
pub fn add_points(&mut self, points: &[Vec<T>]) -> Result<(), ErrorKind>
pub fn vertices_indices(&self) -> (Vec<Vec<T>>, Vec<usize>)
pub fn volume(&self) -> T
pub fn support_point(&self, direction: &[T]) -> Result<Vec<T>, ErrorKind>